emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 2bf0b3b: Fix problems in autorevert-tests


From: Michael Albinus
Subject: [Emacs-diffs] master 2bf0b3b: Fix problems in autorevert-tests
Date: Mon, 20 May 2019 04:14:25 -0400 (EDT)

branch: master
commit 2bf0b3bf6183c1da9b5dee789c7aa3241ca93441
Author: Michael Albinus <address@hidden>
Commit: Michael Albinus <address@hidden>

    Fix problems in autorevert-tests
    
    * test/lisp/autorevert-tests.el (auto-revert--deftest-remote):
    Fix typo.
    (auto-revert-test02-auto-revert-deleted-file): On emba, there are
    no stopped events.
---
 test/lisp/autorevert-tests.el | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/test/lisp/autorevert-tests.el b/test/lisp/autorevert-tests.el
index 0cc5b9c..040dbb4 100644
--- a/test/lisp/autorevert-tests.el
+++ b/test/lisp/autorevert-tests.el
@@ -150,7 +150,7 @@ This expects `auto-revert--messages' to be bound by
        (tramp-dissect-file-name temporary-file-directory) nil 'keep-password)
        (condition-case err
            (funcall (ert-test-body ert-test))
-         (error (message "%s" err) (signal car err cdr err))))))
+         (error (message "%s" err) (signal (car err) (cdr err)))))))
 
 (ert-deftest auto-revert-test00-auto-revert-mode ()
   "Check autorevert for a file."
@@ -310,8 +310,9 @@ This expects `auto-revert--messages' to be bound by
             ;; notification should be disabled, falling back to
             ;; polling.
             (should (string-match "any text" (buffer-string)))
             ;; With w32notify, the 'stopped' events are not sent.
             (or (eq file-notify--library 'w32notify)
+                (getenv "EMACS_EMBA_CI")
                 (should-not auto-revert-notify-watch-descriptor))
 
             ;; Once the file has been recreated, the buffer shall be
@@ -310,8 +310,9 @@ This expects `auto-revert--messages' to be bound by
             ;; polling.
             (should (string-match "any text" (buffer-string)))
-            ;; With w32notify, the 'stopped' events are not sent.
+            ;; With w32notify, and on emba, the `stopped' events are not sent.
             (or (eq file-notify--library 'w32notify)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]